Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetZapLogFunc ¶
func GetZapLogFunc(zapLogger *zap.Logger, before func(msg ectologger.EctoLogMessage) ectologger.EctoLogMessage) ectologger.EctoLogFunc
GetZapLogFunc returns a log function that logs to the provided zap logger before is a function that is called before the log message is logged. It can be used to modify the log message or add additional fields to it.
func NewZapEctoLogger ¶
func NewZapEctoLogger(zapLogger *zap.Logger, before func(msg ectologger.EctoLogMessage) ectologger.EctoLogMessage) ectologger.Logger
NewZapEctoLogger returns a new EctoLogger that logs to the provided zap logger before is an optional function that is called before the log message is logged. It can be used to modify the log message or add additional fields to it.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.